@@ -84,15 +84,16 @@ static int bug_count = 0;
 static GHashTable *apps = NULL;
 
 static const GOptionEntry options[] = {
-	{ "name",       '\0', 0, G_OPTION_ARG_STRING,   &gopt_data.name,        N_("Name of contact"),                    N_("NAME") },
-	{ "email",      '\0', 0, G_OPTION_ARG_STRING,   &gopt_data.email,       N_("Email address of contact"),           N_("EMAIL") },
-	{ "package",    '\0', 0, G_OPTION_ARG_STRING,   &gopt_data.package,     N_("Package containing the program"),     N_("PACKAGE") },
-	{ "package-ver",'\0', 0, G_OPTION_ARG_STRING,   &gopt_data.package_ver, N_("Version of the package"),             N_("VERSION") },
-	{ "appname",    '\0', 0, G_OPTION_ARG_FILENAME, &gopt_data.app_file,    N_("File name of crashed program"),       N_("FILE") },
-	{ "pid",        '\0', 0, G_OPTION_ARG_INT,      &gopt_data.pid,         N_("PID of crashed program"),             N_("PID") },
-	{ "core",       '\0', 0, G_OPTION_ARG_FILENAME, &gopt_data.core_file,   N_("Core file from program"),             N_("FILE") },
-	{ "include",    '\0', 0, G_OPTION_ARG_FILENAME, &gopt_data.include_file,N_("Text file to include in the report"), N_("FILE") },
-	{ "kill",       '\0', 0, G_OPTION_ARG_INT,      &gopt_data.kill,        N_("PID of the program to kill after the report"), N_("KILL") },
+	{ "name",       '\0', 0, G_OPTION_ARG_STRING,   &gopt_data.name,          N_("Name of contact"),                         N_("NAME") },
+	{ "email",      '\0', 0, G_OPTION_ARG_STRING,   &gopt_data.email,         N_("Email address of contact"),                N_("EMAIL") },
+	{ "package",    '\0', 0, G_OPTION_ARG_STRING,   &gopt_data.package,       N_("Package containing the program"),          N_("PACKAGE") },
+	{ "package-ver",'\0', 0, G_OPTION_ARG_STRING,   &gopt_data.package_ver,   N_("Version of the package"),                  N_("VERSION") },
+	{ "appname",    '\0', 0, G_OPTION_ARG_FILENAME, &gopt_data.app_file,      N_("File name of crashed program"),            N_("FILE") },
+	{ "pid",        '\0', 0, G_OPTION_ARG_INT,      &gopt_data.pid,           N_("PID of crashed program"),                  N_("PID") },
+	{ "core",       '\0', 0, G_OPTION_ARG_FILENAME, &gopt_data.core_file,     N_("Core file from program"),                  N_("FILE") },
+	{ "include",    '\0', 0, G_OPTION_ARG_FILENAME, &gopt_data.include_file,  N_("Text file to include in the report"),      N_("FILE") },
+	{ "minidump",   '\0', 0, G_OPTION_ARG_FILENAME, &gopt_data.minidump_file, N_("MiniDump file with info about the crash"), N_("FILE") },
+	{ "kill",       '\0', 0, G_OPTION_ARG_INT,      &gopt_data.kill,          N_("PID of the program to kill after the report"), N_("KILL") },
 	{ NULL }
 };
 
@@ -1250,6 +1251,29 @@ unknown_app_finished (GladeXML *xml)
 	gtk_widget_realize (glade_xml_get_widget (xml, "details-view"));
 }
 
+
+static void
+send_minidump (GladeXML *xml)
+{
+	/* FIXME: Implement the MiniDump sending code */
+	GtkWidget *button;
+
+	button = glade_xml_get_widget (xml, "close-button");
+	gtk_button_set_label (GTK_BUTTON (button), _("_Close"));
+	gtk_button_set_use_underline (GTK_BUTTON (button), TRUE);
+
+	/* don't need user input, so hide these widgets */
+	gtk_widget_hide (glade_xml_get_widget (xml, "final-box"));
+	gtk_widget_hide (glade_xml_get_widget (xml, "progressbar"));
+	gtk_widget_hide (glade_xml_get_widget (xml, "send-button"));
+	
+	gtk_label_set_text (GTK_LABEL (glade_xml_get_widget (xml, "main-text")),
+			    _("Your application has crashed. Information about the crash has been successfully collected.\n\n"
+	                      "However we are working on GNOME debug server to handle correctly this information.\n\n"));
+}
+
+
+
 static void
 gdb_finished_unknown_app (const gchar *stacktrace, gpointer data)
 {
@@ -1668,6 +1692,7 @@ main (int argc, char *argv[])
 	g_set_application_name (_("Bug Buddy"));
 	gtk_window_set_default_icon_name ("bug-buddy");
 
+
 	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
 				       "bug-buddy.glade", TRUE, NULL);
 	if (s)
@@ -1700,8 +1725,10 @@ main (int argc, char *argv[])
 		return 0;
 	}	
 
-	if (gopt_data.app_file && gopt_data.pid == 0 && gopt_data.include_file == NULL) {
-		buddy_error (NULL, _("Either --pid or --include arguments are required.\n"));	
+	if (gopt_data.app_file && gopt_data.pid == 0 && 
+            gopt_data.include_file == NULL && 
+            gopt_data.minidump_file == NULL) {
+		buddy_error (NULL, _("Either --pid , --include or --minidump arguments are required.\n"));	
 		g_object_unref (program);
 		return 0;
 	}	
@@ -1781,7 +1808,9 @@ main (int argc, char *argv[])
 	 		* the main loop (and kill gdb) if the user wants to quit before gdb is finished */
 			g_object_set_data (G_OBJECT (xml), "sourceid", GUINT_TO_POINTER (source_id));
 		} else {
-			if (app == NULL) {
+			if (gopt_data.minidump_file != NULL) {
+				send_minidump (xml);
+			} else if (app == NULL) {
 				unknown_app_finished (xml);
 			} else {
 				known_app_finished (xml);
