@@ -48,15 +48,16 @@ typedef struct {
 	/* file to include */
 	gchar *include_file;
 
+	/* MiniDump file */
+	gchar *minidump_file;
+
 	/* pid to kill after the bug report */
 	int kill;
 } GOptionData;
 
 enum {
-	LOADING_INFO,
-	DEBUGGING,
-	SENDING,
-	DONE
+	BUG_TYPE_CRASH,
+	BUG_TYPE_REQUEST
 };
 
 
